import{v as n,Q as l,aa as c,c as u,y as h,E as f,l as w,K as a,L as b}from"./index-20675090.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-8114fc79.js";import"./ListviewItem-ea07a19b.js";import"./VBadge-778cac01.js";import"./ListItem-e092a77b.js";import"./forwardRefs-67412654.js";import"./VMenu-ae4158ef.js";import"./VCheckboxBtn-bbfa74a1.js";import"./VSlideGroup-14bb6bf6.js";import"./VCard-30020028.js";import"./VCardText-5e149cd1.js";import"./VTooltip-cf009865.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-4e768a3d.js";import"./contextmenu-ec90c658.js";import"./Alert-daf9024b.js";import"./Container-e8fef44d.js";/* empty css              */import"./VToolbar-7174c765.js";import"./VTextField-8bb22937.js";import"./VVirtualScroll-b47ffb64.js";const A=n({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:o}=l();c();const p=u(()=>!t.path||t.path=="root"?o("browse"):a("bp6")?o("browse")+" | "+t.path:a("bp3")?t.path:o("browse")),i=async function(e){const r=[];return await b.browse(t.path,m=>{r.push(...m)}),r};return(e,r)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:e.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{A as default};
