import{c as r,a6 as c,p as i,g as u,u as d,l as p,y as f,z as v,Z as m,G as _,n as C,A as y,$ as g}from"./index-20675090.js";import{a as P}from"./ListItem-e092a77b.js";/* empty css              */import{a as k,d as V,i as $}from"./forwardRefs-67412654.js";const h={props:{variant:{type:String,default:"default",validator:e=>["default","panel"].includes(e)}},setup(e,n){const a=r(()=>({class:"container-default"})),t=r(()=>({class:c.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(e.variant){case"default":return a.value;case"panel":return t.value;default:return a.value}})}}};const w=i({fluid:{type:Boolean,default:!1},...k(),...V()},"VContainer"),x=u()({name:"VContainer",props:w(),setup(e,n){let{slots:a}=n;const{rtlClasses:t}=d();return $(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},t.value,e.class],style:e.style},a)),{}}});function b(e,n,a,t,o,l){return f(),v(x,C(t.btnProps,{variant:"default",fluid:""}),m({_:2},[_(e.$slots,(B,s)=>({name:s,fn:y(()=>[g(e.$slots,s)])}))]),1040)}const D=P(h,[["render",b]]);export{D as C};
