import{m as U,a as w,u as H,b as h,c as I}from"./VCheckboxBtn-bbfa74a1.js";import{p as y,az as G,g,h as S,ap as B,c as v,aI as R,l as V,n as p,v as z,y as M,z as D,x as L,H as C,L as N,d as W,e as j,r as q}from"./index-20675090.js";import{i as T,a as E,n as J,d as K,p as Q,x as X,y as Y,H as Z}from"./forwardRefs-67412654.js";import{B as _}from"./ListItem-e092a77b.js";import{m as ee,a as te,f as x}from"./VMenu-ae4158ef.js";const oe=y({...U(),...G(w(),["inline"])},"VCheckbox"),ce=g()({name:"VCheckbox",inheritAttrs:!1,props:oe(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,s){let{attrs:t,slots:o}=s;const a=S(e,"modelValue"),{isFocused:r,focus:n,blur:i}=H(e),u=B(),l=v(()=>e.id||`checkbox-${u}`);return T(()=>{const[b,k]=R(t),P=h.filterProps(e),c=I.filterProps(e);return V(h,p({class:["v-checkbox",e.class]},b,P,{modelValue:a.value,"onUpdate:modelValue":d=>a.value=d,id:l.value,focused:r.value,style:e.style}),{...o,default:d=>{let{id:m,messagesId:f,isDisabled:A,isReadonly:F}=d;return V(I,p(c,{id:m.value,"aria-describedby":f.value,disabled:A.value,readonly:F.value},k,{modelValue:a.value,"onUpdate:modelValue":O=>a.value=O,onFocus:n,onBlur:i}),o)}})}),{}}}),de=z({__name:"FavoriteButton",props:{item:{}},setup(e){const s=e;return(t,o)=>{var a;return M(),D(_,p(s,{variant:"list",icon:(a=t.item)!=null&&a.favorite?"mdi-heart":"mdi-heart-outline",title:t.$t("tooltip.favorite"),onClick:[o[0]||(o[0]=r=>L(N).toggleFavorite(t.item)),o[1]||(o[1]=C(()=>{},["prevent"])),o[2]||(o[2]=C(()=>{},["stop"]))]}),null,16,["icon","title"])}}});const $=Symbol.for("vuetify:v-item-group"),ae=y({...E(),...J({selectedClass:"v-item--selected"}),...K(),...W()},"VItemGroup"),me=g()({name:"VItemGroup",props:ae(),emits:{"update:modelValue":e=>!0},setup(e,s){let{slots:t}=s;const{themeClasses:o}=j(e),{isSelected:a,select:r,next:n,prev:i,selected:u}=Q(e,$);return()=>V(e.tag,{class:["v-item-group",o.value,e.class],style:e.style},{default:()=>{var l;return[(l=t.default)==null?void 0:l.call(t,{isSelected:a,select:r,next:n,prev:i,selected:u.value})]}})}}),ve=g()({name:"VItem",props:X(),emits:{"group:selected":e=>!0},setup(e,s){let{slots:t}=s;const{isSelected:o,select:a,toggle:r,selectedClass:n,value:i,disabled:u}=Y(e,$);return()=>{var l;return(l=t.default)==null?void 0:l.call(t,{isSelected:o.value,selectedClass:n.value,select:a,toggle:r,value:i.value,disabled:u.value})}}});const se=y({id:String,text:String,...G(ee({closeOnBack:!1,location:"end",locationStrategy:"connected",eager:!0,minWidth:0,offset:10,openOnClick:!1,openOnHover:!0,origin:"auto",scrim:!1,scrollStrategy:"reposition",transition:!1}),["absolute","persistent"])},"VTooltip"),pe=g()({name:"VTooltip",props:se(),emits:{"update:modelValue":e=>!0},setup(e,s){let{slots:t}=s;const o=S(e,"modelValue"),{scopeId:a}=te(),r=B(),n=v(()=>e.id||`v-tooltip-${r}`),i=q(),u=v(()=>e.location.split(" ").length>1?e.location:e.location+" center"),l=v(()=>e.origin==="auto"||e.origin==="overlap"||e.origin.split(" ").length>1||e.location.split(" ").length>1?e.origin:e.origin+" center"),b=v(()=>e.transition?e.transition:o.value?"scale-transition":"fade-transition"),k=v(()=>p({"aria-describedby":n.value},e.activatorProps));return T(()=>{const P=x.filterProps(e);return V(x,p({ref:i,class:["v-tooltip",e.class],style:e.style,id:n.value},P,{modelValue:o.value,"onUpdate:modelValue":c=>o.value=c,transition:b.value,absolute:!0,location:u.value,origin:l.value,persistent:!0,role:"tooltip",activatorProps:k.value,_disableGlobalStack:!0},a),{activator:t.activator,default:function(){var f;for(var c=arguments.length,d=new Array(c),m=0;m<c;m++)d[m]=arguments[m];return((f=t.default)==null?void 0:f.call(t,...d))??e.text}})}),Z({},i)}});export{pe as V,de as _,ce as a,me as b,ve as c};
