import{a as g,i as b,l as P,k as V,G as k,m as G,O as H,b as J,W as U,z as W,A as X,c as Y,X as $,d as q,B as K,U as Q,u as Z,E as ee,o as ae,P as te,f as ne,R as de,C as ie,D as le,g as se,Y as ce,s as re,T as ue,F as oe}from"./forwardRefs-67412654.js";import{g as f,k as ve,l as n,p as S,aJ as u,F as A,d as me,e as ye,c as p,af as ke,ae as ge}from"./index-20675090.js";import{h as be,d as h}from"./VMenu-ae4158ef.js";import{a as fe,V as Ce}from"./VCardText-5e149cd1.js";const Ie=f()({name:"VCardActions",props:g(),setup(e,i){let{slots:t}=i;return ve({VBtn:{slim:!0,variant:"text"}}),b(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),Ve=be("v-card-subtitle"),Ae=S({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:[String,Number],title:[String,Number],...g(),...P()},"VCardItem"),pe=f()({name:"VCardItem",props:Ae(),setup(e,i){let{slots:t}=i;return b(()=>{var s;const a=!!(e.prependAvatar||e.prependIcon),o=!!(a||t.prepend),l=!!(e.appendAvatar||e.appendIcon),v=!!(l||t.append),m=!!(e.title!=null||t.title),y=!!(e.subtitle!=null||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[o&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(k,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},t.prepend):n(A,null,[e.prependAvatar&&n(h,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&n(V,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null)])]),n("div",{class:"v-card-item__content"},[m&&n(fe,{key:"title"},{default:()=>{var d;return[((d=t.title)==null?void 0:d.call(t))??e.title]}}),y&&n(Ve,{key:"subtitle"},{default:()=>{var d;return[((d=t.subtitle)==null?void 0:d.call(t))??e.subtitle]}}),(s=t.default)==null?void 0:s.call(t)]),v&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(k,{key:"append-defaults",disabled:!l,defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},t.append):n(A,null,[e.appendIcon&&n(V,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&n(h,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])])])}),{}}}),he=S({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:[String,Number],text:[String,Number],title:[String,Number],...G(),...g(),...P(),...H(),...J(),...U(),...W(),...X(),...Y(),...$(),...q(),...me(),...K({variant:"elevated"})},"VCard"),Be=f()({name:"VCard",directives:{Ripple:Q},props:he(),setup(e,i){let{attrs:t,slots:a}=i;const{themeClasses:o}=ye(e),{borderClasses:l}=Z(e),{colorClasses:v,colorStyles:m,variantClasses:y}=ee(e),{densityClasses:s}=ae(e),{dimensionStyles:d}=te(e),{elevationClasses:x}=ne(e),{loaderClasses:T}=de(e),{locationStyles:B}=ie(e),{positionClasses:D}=le(e),{roundedClasses:L}=se(e),c=ce(e,t),_=p(()=>e.link!==!1&&c.isLink.value),r=p(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return b(()=>{const N=_.value?"a":e.tag,R=!!(a.title||e.title!=null),F=!!(a.subtitle||e.subtitle!=null),E=R||F,O=!!(a.append||e.appendAvatar||e.appendIcon),M=!!(a.prepend||e.prependAvatar||e.prependIcon),j=!!(a.image||e.image),w=E||M||O,z=!!(a.text||e.text!=null);return ke(n(N,{class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},o.value,l.value,v.value,s.value,x.value,T.value,D.value,L.value,y.value,e.class],style:[m.value,d.value,B.value,e.style],href:c.href.value,onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},{default:()=>{var C;return[j&&n("div",{key:"image",class:"v-card__image"},[a.image?n(k,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(re,{key:"image-img",cover:!0,src:e.image},null)]),n(ue,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),w&&n(pe,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),z&&n(Ce,{key:"text"},{default:()=>{var I;return[((I=a.text)==null?void 0:I.call(a))??e.text]}}),(C=a.default)==null?void 0:C.call(a),a.actions&&n(Ie,null,{default:a.actions}),oe(r.value,"v-card")]}}),[[ge("ripple"),r.value&&e.ripple]])}),{}}});export{Be as V,Ve as a,Ie as b};
