.container-default{padding:15px}.container-panels-light{background:#f5f5f5}@media (min-width: 1920px){.container-default{max-width:unset!important}}@media (min-width: 1280px){.container-default{max-width:unset!important}}@media (min-width: 960px){.container{max-width:unset!important}}
