.panel-item{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-selected{background-image:linear-gradient(90deg,rgb(var(--v-theme-surface-light)) 0%,rgb(var(--v-theme-background)) 35%)}.panel-item-idle{opacity:.5}.panel-item-details{align-items:center;margin-left:0!important;padding-left:0!important;padding-right:0!important}.home-card{min-width:80px;text-align:center;padding-top:12px;padding-bottom:8px}.widget-row{margin-bottom:20px}.v-slide-group__prev{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled{visibility:hidden;margin-right:-15px}.v-slide-group__next{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled{visibility:hidden}
